@@ -1,20 +1,17 @@
 /*
-	Lightweight tools for R and c++ integration.
-    Copyright (C) 2014 Martin Vincent
-
-    This program is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 3 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>
-*/
+ Lightweight tools for R and c++ integration.
+ Copyright (C) 2012 Martin Vincent
+ This program is free software: you can redistribute it and/or modify
+ it under the terms of the GNU General Public License as published by
+ the Free Software Foundation, either version 3 of the License, or
+ (at your option) any later version.
+ This program is distributed in the hope that it will be useful,
+ but WITHOUT ANY WARRANTY; without even the implied warranty of
+ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ GNU General Public License for more details.
+ You should have received a copy of the GNU General Public License
+ along with this program.  If not, see <http://www.gnu.org/licenses/>
+ */
 
 #ifndef RLIST_H_
 #define RLIST_H_
@@ -93,7 +90,7 @@ public:
 		{
 			if (name.compare(names[index]) == 0)
 			{
-				return static_cast<int>(index);
+				return index;
 			}
 		}
 
@@ -104,4 +101,9 @@ public:
 };
 
 
+class elements {
+public:
+  virtual rList as_rList() const;
+};
+
 #endif /* RLIST_H_ */
