@@ -15,17 +15,15 @@ parameterWeights <-  matrix(1, nrow = length(levels(sampleGrouping)), ncol = nco
 alpha <- 0.5
 d <- 20L
 lambda.min <- 0.5
-algorithm.config <- sgl.standard.config 
 
 # create data
 data <- create.sgldata(x, y, weights, sampleGrouping)
-lambda <- sgl_lambda_sequence("sgl_test_dense", "sglOptim", data, covariateGrouping, groupWeights, parameterWeights, alpha = alpha, d = d, lambda.min, algorithm.config)
-fit1a.cv <- sgl_cv("sgl_test_dense", "sglOptim", data, covariateGrouping, groupWeights, parameterWeights, alpha, lambda, fold = 2L, cv.indices = list(), max.threads = 1L, algorithm.config)
+lambda <- sgl_lambda_sequence("sgl_test_dense", "sglOptim", data, covariateGrouping, groupWeights, parameterWeights, alpha = alpha, d = d, lambda.min)
+fit1a.cv <- sgl_cv("sgl_test_dense", "sglOptim", data, covariateGrouping, groupWeights, parameterWeights, alpha, lambda, fold = 2L, cv.indices = list())
 
 data <- create.sgldata(x, y, weights, sampleGrouping, sparseX = TRUE)
 
 #Seed used for cv splitting
 set.seed(300)
 
-fit1b.cv <- sgl_cv("sgl_test_sparse", "sglOptim", data, covariateGrouping, groupWeights, parameterWeights, alpha, lambda, fold = 2L, cv.indices = list(), max.threads = 1L, algorithm.config)
-
+fit1b.cv <- sgl_cv("sgl_test_sparse", "sglOptim", data, covariateGrouping, groupWeights, parameterWeights, alpha, lambda, fold = 2L, cv.indices = list())
